# This short Python V2 demonstration program remotely controls a NET16PRMx board
# using TCP/IP and the normal EasyDaq command set, demostrating input and output.

import socket    # used for TCP/IP communication
import time      # used for display
import random    # generate pseudo-random numbers
import sys       # display of data read back from the board.
import signal    # intercept SIGINT (Ctrl-C) to end demo.
import sys

# Define the IP address of the NET16.
TCP_IP = '10.26.177.105' # Set this to the IP address of your NET16
TCP_PORT = 10001 # Do not change this - it is pre-defined in the Lantronix XPort module.
BUFFER_SIZE = 1 # How many bytes to read back from board

# Introduction
print ("\nEasyDaq TCP/IP demonstration of the NET16 board")
print ("(Hit Ctrl-c to end)\n")
time.sleep(1)

# Open TCP/IP socket
s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
s.connect((TCP_IP, TCP_PORT))

# Define a signal handler to catch when the user quits using Ctrl-C and then tidy up
def signal_handler(signal, frame):
 print('\n\n\n      *** Thank you for trying the EasyDaq NET16 *** \nFor further information please visit http://www.easydaq.co.uk\n')
 MESSAGE = '\x43\x00' # PIC port B to off
 s.send(MESSAGE)
 time.sleep(0.1)
 MESSAGE = '\x46\x00' # PIC port C to off
 s.send(MESSAGE)
 time.sleep(0.1)
 s.close()
 sys.exit(0)

signal.signal(signal.SIGINT, signal_handler) # Register the signal handler

# Configure the NET16 ports for input/output
MESSAGE = '\x42\x00\x45\x00\x48\xFF' # Set PIC port B,C to O/P, PIC port D to I/P
s.send(MESSAGE)
time.sleep(0.100) # Allow the board to settle.

# Send random numbers to RLY1 to RLY16, whilst reading from PIC port D and displaying value

while True:
 MESSAGE = '\x43'+chr(random.randint(0,255)); # Set PIC port B to a pseudo-random number
 s.send(MESSAGE);
 time.sleep(0.100);
 MESSAGE = '\x46'+chr(random.randint(0,255)); # Set PIC port C to a pseudo-random number
 s.send(MESSAGE);
 time.sleep(0.100);

 MESSAGE = '\x47\x00\x0D\x0A' # Set PIC Read port D;
 s.send(MESSAGE);
 sys.stdout.write("\r"+ time.ctime() + ":  " + format(ord(s.recv(BUFFER_SIZE)),'b').zfill(8));
 sys.stdout.flush()

# Tidy up...
MESSAGE = '\x43\x00' # PIC port B to off
s.send(MESSAGE)
time.sleep(0.1)
MESSAGE = '\x46\x00' # PIC port C to off
s.send(MESSAGE)
time.sleep(0.1)

s.close()
sys.exit(0)
